Description: Make tart, dry and bubbly hard cider at home with this 1 Gallon Hard Cider Kit.
Keywords: Brooklyn Brew Shop, hard cider kit, apple cider, 1 gallon, hard cider

- Account
- Cart
- Checkout
- Log In

Share by email on twitter on Facebook on Pinterest on The Fancy on StumbleUpon on Reddit on Tumblr on Google+ anywhere: http://thema.sh/HardCiderKit

# Hard Cider Kit

$40.00
Add Items to Cart Qty:
Our Hard Cider Kit has everything you need (other than some fresh cider) for 3 batches of tart, dry and bubbly hard cider. Making hard cider is even easier than making beer and making beer is pretty easy!
Fast & Free shipping for orders over $45
*domestic orders excluding Alaska & Hawaii

- Useful Additions
- Details

##### Beer Making Kit: Everyday IPA® $40.00 | ##### Hard Cider Refill Pack $12.00 | ##### Beer Bottle Set $22.00 | ##### Bottle Capper & Caps $20.00

Includes | 1 Gallon Glass Fermenter, Airlock, Tubing, Tubing Clamp, 3 Packets of Sanitizer, 3 Packets of Hard Cider Yeast, and Screw-Cap Stopper
ABV | 4-5% ABV
Profile | NEW! Make tart, dry and bubbly hard cider!